==> shardingsphere-sharding-distsql-statement-5.1.0-sources.jar: org/apache/shardingsphere/sharding/distsql/parser/statement/DropShardingBindingTableRulesStatement.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sharding.distsql.parser.statement;

import lombok.Getter;
import lombok.RequiredArgsConstructor;
import org.apache.shardingsphere.distsql.parser.statement.rdl.drop.DropRuleStatement;
import org.apache.shardingsphere.sharding.distsql.parser.segment.BindingTableRuleSegment;

import java.util.Collection;
import java.util.LinkedList;

/**
 * Drop sharding binding table rules statement.
 */
@RequiredArgsConstructor
@Getter
public final class DropShardingBindingTableRulesStatement extends DropRuleStatement {
    
    private final Collection<BindingTableRuleSegment> rules;
    
    /**
     * Get binding groups.
     *
     * @return binding groups
     */
    public Collection<String> getBindingGroups() {
        Collection<String> result = new LinkedList<>();
        for (BindingTableRuleSegment each : rules) {
            result.add(each.getTableGroups());
        }
        return result;
    }
}

==> shardingsphere-sharding-distsql-statement-5.1.1-sources.jar: org/apache/shardingsphere/sharding/distsql/parser/statement/DropShardingBindingTableRulesStatement.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sharding.distsql.parser.statement;

import lombok.Getter;
import lombok.RequiredArgsConstructor;
import org.apache.shardingsphere.distsql.parser.statement.rdl.drop.DropRuleStatement;
import org.apache.shardingsphere.sharding.distsql.parser.segment.BindingTableRuleSegment;

import java.util.Collection;
import java.util.LinkedList;

/**
 * Drop sharding binding table rules statement.
 */
@RequiredArgsConstructor
@Getter
public final class DropShardingBindingTableRulesStatement extends DropRuleStatement {
    
    private final Collection<BindingTableRuleSegment> rules;
    
    public DropShardingBindingTableRulesStatement(final boolean containsExistClause, final Collection<BindingTableRuleSegment> rules) {
        setContainsExistClause(containsExistClause);
        this.rules = rules;
    }
    
    /**
     * Get binding groups.
     *
     * @return binding groups
     */
    public Collection<String> getBindingGroups() {
        Collection<String> result = new LinkedList<>();
        for (BindingTableRuleSegment each : rules) {
            result.add(each.getTableGroups());
        }
        return result;
    }
}
